/*
 * Funktionen.c
 *
 * Created: 11.09.2017 10:23:50
 *  Author: ingo
 */ 

#include "Funktionen.h"

void Init_AVR ( void )
{
	//LEDs
	DDRA |= (1<<PA1) | (1<<PA2) | (1<<PA3);
	
	//Debug Pin
	DDRB |= (1<<PB0);
	
	// Speaker
	DDRB |= (1<<PB1);
	
	//PWM
	DDRA |= (1<<PA7);
	
	//Systick + PWM
	OCR0A = 199;							
	TCCR0A |= (1<<COM0B1);					// Clear on Compare Match (non inverting PWM)
	TCCR0A |= (1<<WGM00) | (1<<WGM01);		// Fast-PWM; TOP = OCR0A
	TCCR0B |= (1<<WGM02);					// Fast-PWM; TOP = OCR0A
	TCCR0B |= (1<<CS01);					// 8MHz/(200*8) = 5kHZ
	TIMSK0 |= (1<<TOIE0);					// Interrupt on Overflow
	TOCPMCOE |= (1<<TOCC6OE);				// Output enable

	//ADC
	ADCSRA |= (1<<ADEN) | (1<<ADPS1) | (1<<ADPS2); // Enable ADC; Prescaler = 64
	
	// Impulse Counter
	TCCR1B |= (1<<CS10) | (1<<CS11) | (1<<CS12);	// Trigger on rising Edge
	
	// global Interrupt enable
	sei();
}


void Configure_LED ( const uint8_t Colour, const uint8_t State )
{
	if ( Colour == ALL_LED && State == CLEAR ){
		PORTA &= ~((1<<LED_GE) | (1<<LED_GN) | (1<<LED_RT));	
	}else if ( Colour == LED_GN ){
		PORTA &= ~((1<<LED_GE) | (1<<LED_RT) );	
	}else if ( Colour == LED_GE ){
		PORTA &= ~((1<<LED_GN) | (1<<LED_RT) );
	}else if ( Colour == LED_RT ){
		PORTA &= ~((1<<LED_GE) | (1<<LED_GN) );
	}
	
	
	if ( Colour <= PA3 ){
		if ( State == SET ){
			PORTA |= (1<<Colour);
		}else if (State == TOGGLE ){
			PINA |= (1<<Colour);
		}else{
			PORTA &= ~(1<<Colour);
		}
	}
}

uint16_t GetTimerDiff ( void )
{
	static uint16_t OldValue = 0;
	uint16_t Diff = 0;
	uint16_t NewValue = TCNT1;
	Diff = NewValue - OldValue;
	OldValue = NewValue;
	return Diff;
}
